==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/es.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Falló al acceder a los tokens solicitados. Verifique que su clave de app y la clave secreta sean correctas.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Falló al acceder a los tokens solicitados. Verifique que su clave de app y la clave secreta sean correctas.",
    "Please provide a valid app key and secret." : "Por favor facilite una clave de app y una clave secreta válidas.",
    "Step 1 failed. Exception: %s" : "El paso 1 falló. Excepción: %s",
    "Step 2 failed. Exception: %s" : "El paso 2 falló. Excepción: %s",
    "External storage" : "Almacenamiento externo",
    "Storage with id \"%i\" not found" : "No se ha encontrado almacenamiento con id \"%i\"",
    "Invalid backend or authentication mechanism class" : "Sistema o mecanismo de autentificación inválido",
    "Invalid mount point" : "Punto de montaje no válido",
    "Objectstore forbidden" : "Objeto de almacenaje prohibido",
    "Invalid storage backend \"%s\"" : "Motor de almacenamiento no válido «%s»",
    "Not permitted to use backend \"%s\"" : "No se permite usar el mecanismo \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "No está permitido usar el mecanismo de autentificación \"%s\"",
    "Unsatisfied backend parameters" : "Los parámetros del sistema no son válidos",
    "Unsatisfied authentication mechanism parameters" : "Los parámetros del mecanismo de autentificación no son válidos",
    "Insufficient data: %s" : "Datos insuficientes: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "El almacenamiento con id \"%i\" no es editable por usuarios",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Grant access" : "Conceder acceso",
    "Access granted" : "Acceso concedido",
    "Error configuring OAuth1" : "Error al configurar OAuth1",
    "Error configuring OAuth2" : "Error al configurar OAuth2",
    "Generate keys" : "Generar claves",
    "Error generating key pair" : "Error al generar el par de claves",
    "Enable encryption" : "Habilitar cifrado",
    "Enable previews" : "Habilitar previsualizaciones",
    "Enable sharing" : "Habilitar comparto",
    "Check for changes" : "Comprobar si hay cambios",
    "Never" : "Nunca",
    "Once every direct access" : "Una vez cada acceso directo",
    "All users. Type to select user or group." : "Todos los usuarios. Teclee para seleccionar un usuario o grupo.",
    "(group)" : "(grupo)",
    "Admin defined" : "Admin definido",
    "Saved" : "Guardado",
    "Empty response from the server" : "Respuesta vacía desde el servidor",
    "Couldn't access. Please logout and login to activate this mount point" : "No se puede acceder. Por favor cierra sesión e iníciala de nuevo para activar este punto de montaje",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "No se puede obtener información acerca del servidor de OwnCloud: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "No se puede obtener la lista de los puntos de montaje externos: {type}",
    "There was an error with message: " : "Hubo un error con el mensaje:",
    "External mount error" : "Error de montaje externo",
    "external-storage" : "almacenamiento-externo",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "No se puede obtener la lista de unidades de red y sus puntos de montaje de Windows: respuesta vacía desde el servidor",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Algunos de los puntos de montaje externos configurados no están conectados. Por favor, haga clic en la fila roja (s) para obtener más información",
    "Please enter the credentials for the {mount} mount" : "Por favor introduzca los credenciales para el punto de montaje {mount}",
    "Username" : "Nombre de usuario",
    "Password" : "Contraseña",
    "Credentials saved" : "Credenciales guardados",
    "Credentials saving failed" : "Guardado de credenciales fallido",
    "Credentials required" : "Credenciales requeridos",
    "Save" : "Guardar",
    "Access key" : "Clave de acceso",
    "Secret key" : "Clave secreta",
    "Builtin" : "Incorporado",
    "None" : "Ninguno",
    "OAuth1" : "OAuth1",
    "App key" : "App principal",
    "App secret" : "App secreta",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID de Cliente",
    "Client secret" : "Cliente secreto",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Nombre del inquilino",
    "Identity endpoint URL" : "Identidad de punto final URL",
    "Rackspace" : "Espacio de Rack",
    "API key" : "Clave API",
    "Username and password" : "Nombre de usuario y contraseña",
    "Log-in credentials, save in session" : "Iniciar credenciales, guardar en la sesión",
    "RSA public key" : "Clave pública RSA",
    "Public key" : "Clave pública",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Depósito",
    "Hostname" : "Nombre de equipo",
    "Port" : "Puerto",
    "Region" : "Región",
    "Enable SSL" : "Habilitar SSL",
    "Enable Path Style" : "Habilitar Estilo de Ruta",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subcarpeta remota",
    "Secure https://" : "—Seguro— https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Servidor",
    "Secure ftps://" : "—Seguro— ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Local",
    "Location" : "Ubicación",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Raíz",
    "SFTP with secret key login" : "Inicio de sesión SFTP con clave secreta",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Compartir",
    "Domain" : "Dominio",
    "SMB / CIFS using OC login" : "SMB / CIFS que usan acceso OC",
    "Username as share" : "Nombre de usuario como compartir",
    "OpenStack Object Storage" : "Almacenamiento de objeto OpenStack",
    "Service name" : "Nombre del servicio",
    "Request timeout (seconds)" : "Tiempo agotado para petición (segundos)",
    "<b>Note:</b> " : "<b>Nota:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> El soporte de cURL en PHP no está activado o instalado. No se puede montar %s. Pídale al administrador del sistema que lo instale.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> El soporte de FTP en PHP no está activado o instalado. No se puede montar %s. Pídale al administrador del sistema que lo instale.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> \"%s\" no está instalado. No se puede montar %s. Pídale al administrador del sistema que lo instale.",
    "No external storage configured" : "No hay ningún almacenamiento externo configurado",
    "You can add external storages in the personal settings" : "Puede agregar almacenamientos externos en la configuración personal",
    "Name" : "Nombre",
    "Storage type" : "Tipo de almacenamiento",
    "Scope" : "Ámbito",
    "External Storage" : "Almacenamiento externo",
    "Folder name" : "Nombre de la carpeta",
    "Authentication" : "Autentificación",
    "Configuration" : "Configuración",
    "Available for" : "Disponible para",
    "Add storage" : "Añadir almacenamiento",
    "Advanced settings" : "Configuración avanzada",
    "Delete" : "Eliminar",
    "Allow users to mount external storage" : "Permitir a los usuarios montar un almacenamiento externo",
    "Allow users to mount the following external storage" : "Permitir a los usuarios montar el siguiente almacenamiento externo"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/es.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Falló al acceder a los tokens solicitados. Verifique que su clave de app y la clave secreta sean correctas.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Falló al acceder a los tokens solicitados. Verifique que su clave de app y la clave secreta sean correctas.",
    "Please provide a valid app key and secret." : "Por favor facilite una clave de app y una clave secreta válidas.",
    "Step 1 failed. Exception: %s" : "El paso 1 falló. Excepción: %s",
    "Step 2 failed. Exception: %s" : "El paso 2 falló. Excepción: %s",
    "External storage" : "Almacenamiento externo",
    "Storage with id \"%i\" not found" : "No se ha encontrado almacenamiento con id \"%i\"",
    "Invalid backend or authentication mechanism class" : "Sistema o mecanismo de autentificación inválido",
    "Invalid mount point" : "Punto de montaje no válido",
    "Objectstore forbidden" : "Objeto de almacenaje prohibido",
    "Invalid storage backend \"%s\"" : "Motor de almacenamiento no válido «%s»",
    "Not permitted to use backend \"%s\"" : "No se permite usar el mecanismo \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "No está permitido usar el mecanismo de autentificación \"%s\"",
    "Unsatisfied backend parameters" : "Los parámetros del sistema no son válidos",
    "Unsatisfied authentication mechanism parameters" : "Los parámetros del mecanismo de autentificación no son válidos",
    "Insufficient data: %s" : "Datos insuficientes: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "El almacenamiento con id \"%i\" no es editable por usuarios",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Grant access" : "Conceder acceso",
    "Access granted" : "Acceso concedido",
    "Error configuring OAuth1" : "Error al configurar OAuth1",
    "Error configuring OAuth2" : "Error al configurar OAuth2",
    "Generate keys" : "Generar claves",
    "Error generating key pair" : "Error al generar el par de claves",
    "Enable encryption" : "Habilitar cifrado",
    "Enable previews" : "Habilitar previsualizaciones",
    "Enable sharing" : "Habilitar comparto",
    "Check for changes" : "Comprobar si hay cambios",
    "Never" : "Nunca",
    "Once every direct access" : "Una vez cada acceso directo",
    "All users. Type to select user or group." : "Todos los usuarios. Teclee para seleccionar un usuario o grupo.",
    "(group)" : "(grupo)",
    "Admin defined" : "Admin definido",
    "Saved" : "Guardado",
    "Empty response from the server" : "Respuesta vacía desde el servidor",
    "Couldn't access. Please logout and login to activate this mount point" : "No se puede acceder. Por favor cierra sesión e iníciala de nuevo para activar este punto de montaje",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "No se puede obtener información acerca del servidor de OwnCloud: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "No se puede obtener la lista de los puntos de montaje externos: {type}",
    "There was an error with message: " : "Hubo un error con el mensaje:",
    "External mount error" : "Error de montaje externo",
    "external-storage" : "almacenamiento-externo",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "No se puede obtener la lista de unidades de red y sus puntos de montaje de Windows: respuesta vacía desde el servidor",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Algunos de los puntos de montaje externos configurados no están conectados. Por favor, haga clic en la fila roja (s) para obtener más información",
    "Please enter the credentials for the {mount} mount" : "Por favor introduzca los credenciales para el punto de montaje {mount}",
    "Username" : "Nombre de usuario",
    "Password" : "Contraseña",
    "Credentials saved" : "Credenciales guardados",
    "Credentials saving failed" : "Guardado de credenciales fallido",
    "Credentials required" : "Credenciales requeridos",
    "Save" : "Guardar",
    "Access key" : "Clave de acceso",
    "Secret key" : "Clave secreta",
    "Builtin" : "Incorporado",
    "None" : "Ninguno",
    "OAuth1" : "OAuth1",
    "App key" : "App principal",
    "App secret" : "App secreta",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID de Cliente",
    "Client secret" : "Cliente secreto",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Nombre del inquilino",
    "Identity endpoint URL" : "Identidad de punto final URL",
    "Rackspace" : "Espacio de Rack",
    "API key" : "Clave API",
    "Username and password" : "Nombre de usuario y contraseña",
    "Log-in credentials, save in session" : "Iniciar credenciales, guardar en la sesión",
    "RSA public key" : "Clave pública RSA",
    "Public key" : "Clave pública",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Depósito",
    "Hostname" : "Nombre de equipo",
    "Port" : "Puerto",
    "Region" : "Región",
    "Enable SSL" : "Habilitar SSL",
    "Enable Path Style" : "Habilitar Estilo de Ruta",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subcarpeta remota",
    "Secure https://" : "—Seguro— https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Servidor",
    "Secure ftps://" : "—Seguro— ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Local",
    "Location" : "Ubicación",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Raíz",
    "SFTP with secret key login" : "Inicio de sesión SFTP con clave secreta",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Compartir",
    "Domain" : "Dominio",
    "SMB / CIFS using OC login" : "SMB / CIFS que usan acceso OC",
    "Username as share" : "Nombre de usuario como compartir",
    "OpenStack Object Storage" : "Almacenamiento de objeto OpenStack",
    "Service name" : "Nombre del servicio",
    "Request timeout (seconds)" : "Tiempo agotado para petición (segundos)",
    "<b>Note:</b> " : "<b>Nota:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> El soporte de cURL en PHP no está activado o instalado. No se puede montar %s. Pídale al administrador del sistema que lo instale.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> El soporte de FTP en PHP no está activado o instalado. No se puede montar %s. Pídale al administrador del sistema que lo instale.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> \"%s\" no está instalado. No se puede montar %s. Pídale al administrador del sistema que lo instale.",
    "No external storage configured" : "No hay ningún almacenamiento externo configurado",
    "You can add external storages in the personal settings" : "Puede agregar almacenamientos externos en la configuración personal",
    "Name" : "Nombre",
    "Storage type" : "Tipo de almacenamiento",
    "Scope" : "Ámbito",
    "External Storage" : "Almacenamiento externo",
    "Folder name" : "Nombre de la carpeta",
    "Authentication" : "Autentificación",
    "Configuration" : "Configuración",
    "Available for" : "Disponible para",
    "Add storage" : "Añadir almacenamiento",
    "Advanced settings" : "Configuración avanzada",
    "Delete" : "Eliminar",
    "Allow users to mount external storage" : "Permitir a los usuarios montar un almacenamiento externo",
    "Allow users to mount the following external storage" : "Permitir a los usuarios montar el siguiente almacenamiento externo",
    "SMB / CIFS" : "SMB / CIFS",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Algunos de los puntos de montaje externos configurados no están conectados. Por favor, haga clic en la fila roja (s) para obtener más información"
},
"nplurals=2; plural=(n != 1);");
